@@ -24,8 +24,8 @@ from fanstatic import Library, Resource
 # import Zope3 packages
 
 # import local packages
-from ztfy.blog.browser import ztfy_blog_back
 from ztfy.jqueryui import jquery_alerts, jquery_jsonrpc, jquery_color
+from ztfy.skin import ztfy_skin
 
 
 library = Library('ztfy.thesaurus', 'resources')
@@ -34,6 +34,6 @@ ztfy_thesaurus_css = Resource(library, 'css/ztfy.thesaurus.css')
 
 ztfy_thesaurus = Resource(library, 'js/ztfy.thesaurus.js',
                           minified='js/ztfy.thesaurus.min.js',
-                          depends=[ztfy_blog_back, jquery_alerts, jquery_jsonrpc, jquery_color,
+                          depends=[ztfy_skin, jquery_alerts, jquery_jsonrpc, jquery_color,
                                    ztfy_thesaurus_css],
                           bottom=True)
