@@ -46,3 +46,18 @@ class ThesaurusTermsSearchView(MethodPublisher):
                    'caption': term.caption }
                  for term in thesaurus.findTerms(query, extract_name, autoexpand, glob, limit)
                           if allow_archives or (term.status != STATUS_ARCHIVED) ]
+
+    def findTermsWithLabel(self, query, thesaurus_name='', extract_name='',
+                           autoexpand='on_miss', glob='end', limit=20):
+        allow_archives = True
+        if IThesaurus.providedBy(self.context):
+            thesaurus = self.context
+        else:
+            thesaurus = queryUtility(IThesaurus, thesaurus_name)
+            if thesaurus is None:
+                return []
+            allow_archives = False
+        return [ { 'value': term.label,
+                   'caption': term.label }
+                 for term in thesaurus.findTerms(query, extract_name, autoexpand, glob, limit)
+                          if allow_archives or (term.status != STATUS_ARCHIVED) ]
