@@ -99,6 +99,9 @@ class SKOSThesaurusLoaderHandler(XMLThesaurusLoaderHandler):
                 elif element.tag == SKOS + 'altLabel':
                     term = element.attrib.get(RDF + 'resource')
                     if term is not None:
+                        # import synonyms ?
+                        if not configuration.import_synonyms:
+                            continue
                         # link to another synonym resource
                         used_for.append(term)
                         if term not in terms:
